@@ -120,11 +120,12 @@ void OutputJunctions(Nodes *nodes,Segments *segments,Ways *ways,Relations *relat
 
 static void output_junctions(index_t node,double latitude,double longitude)
 {
+ Node *nodep=LookupNode(OSMNodes,node,1);
  Segment *segment;
  Way *firstway;
  int count=0,difference=0;
 
- segment=FirstSegment(OSMSegments,OSMNodes,node,1);
+ segment=FirstSegment(OSMSegments,nodep,1);
  firstway=LookupWay(OSMWays,segment->way,1);
 
  do
@@ -198,14 +199,15 @@ void OutputSuper(Nodes *nodes,Segments *segments,Ways *ways,Relations *relations
 
 static void output_super(index_t node,double latitude,double longitude)
 {
+ Node *nodep=LookupNode(OSMNodes,node,1);
  Segment *segment;
 
- if(!IsSuperNode(LookupNode(OSMNodes,node,1)))
+ if(!IsSuperNode(nodep))
     return;
 
  printf("%.6f %.6f n\n",radians_to_degrees(latitude),radians_to_degrees(longitude));
 
- segment=FirstSegment(OSMSegments,OSMNodes,node,1);
+ segment=FirstSegment(OSMSegments,nodep,1);
 
  do
    {
@@ -278,9 +280,10 @@ void OutputOneway(Nodes *nodes,Segments *segments,Ways *ways,Relations *relation
 
 static void output_oneway(index_t node,double latitude,double longitude)
 {
+ Node *nodep=LookupNode(OSMNodes,node,1);
  Segment *segment;
 
- segment=FirstSegment(OSMSegments,OSMNodes,node,1);
+ segment=FirstSegment(OSMSegments,nodep,1);
 
  do
    {
@@ -359,9 +362,10 @@ void OutputTurnRestrictions(Nodes *nodes,Segments *segments,Ways *ways,Relations
 
 static void output_turnrestriction(index_t node,double latitude,double longitude)
 {
+ Node *nodep=LookupNode(OSMNodes,node,1);
  index_t turnrelation=NO_RELATION;
 
- if(!IsTurnRestrictedNode(LookupNode(OSMNodes,node,1)))
+ if(!IsTurnRestrictedNode(nodep))
     return;
 
  turnrelation=FindFirstTurnRelation1(OSMRelations,node);
@@ -617,13 +621,14 @@ void OutputLengthLimits(Nodes *nodes,Segments *segments,Ways *ways,Relations *re
 static void output_limits(index_t node,double latitude,double longitude)
 {
 #define MAX_STORED 32
+ Node *nodep=LookupNode(OSMNodes,node,1);
  Segment *segment,*segments[MAX_STORED];
  Way *ways[MAX_STORED];
  int limits[MAX_STORED];
  int count=0;
  int i,j,same=0;
 
- segment=FirstSegment(OSMSegments,OSMNodes,node,1);
+ segment=FirstSegment(OSMSegments,nodep,1);
 
  do
    {
